pygeodesy.rhumb.solve

Package pygeodesy :: Package rhumb :: Module solve |
[frames] | no frames]

# Module solve

Wrapper to invoke Karney's RhumbSolve utility as an (exact) rhumb or rhumb line from either GeographicLib 2.0 or 2.2+.

Note: Set env variable `PYGEODESY_RHUMBSOLVE` to the (fully qualified) path of the `RhumbSolve` executable.

Version: 25.12.06

Classes
| Rhumb8Tuple 8-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12, a12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12`, the area `S12` under the rhumb line and the angular distance `a12` between both points.
| _RhumbSolveBase (INTERNAL) Base class for RhumbSolve and RhumbLineSolve.
| RhumbSolve Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.Rhumb and pygeodesy.RhumbAux.
| RhumbLineSolve Wrapper to invoke Karney's RhumbSolve like a class, similar to pygeodesy.RhumbLine and pygeodesy.RhumbLineAux.
| RhumbSolve7Tuple 7-Tuple `(lat1, lon1, lat2, lon2, azi12, s12, S12)` with lat- `lat1`, `lat2` and longitudes `lon1`, `lon2` of both points, the azimuth of the rhumb line `azi12`, the distance `s12` and the area `S12` under the rhumb line between both points.

Functions
rhumb_intercept(rS, lat1, lon1, lat2, lon2, azi2, s23) |

Variables
| __all__ = `_ALL_LAZY.rhumb_solve`
| rS = `RhumbSolve(name= 'Test')`
| v = `'--verbose' in argv`
| t = `14, 's23', (7, 'lat3'), (11, 'lon3'), (13, 'cos()')`
| r = `rS.Direct(40.6,-73.8, 51, 5.5e6)`
| rlS = `RhumbLineSolve(rS, 40.6,-73.8, 51, name= 'LineTest')`
| p = `rlS.Position(5.5e6)`